
# gender

https://github.com/lmullen/gender

```bash
Rscript scilib/gender/gender_r/gender.R --name tom,lisa,bob
```

## R

```R
install.packages("gender")

# manual install
# https://cran.r-project.org/web/packages/desc/index.html
# https://cran.r-project.org/web/packages/devtools/index.html

library(devtools)
install_github("ropensci/genderdata")
```
